/**
 * apeman bud for env files.
 * @memberof module:apeman-bud-env/lib
 * @function setup
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    stringcase = require('stringcase'),
    uuid = require('uuid'),
    assert = require('assert'),
    _tmpl = require('./_tmpl');

/** @lends setup */
function setup(params) {
    let args = argx(arguments);
    params = args.shift('object') || {};

    let name = params.name,
        pkg = params.pkg;
    assert(name, 'params.name is required.');
    assert(pkg, 'params.pkg is required.');

    return [].concat(name).map((name) => {

        let tmpl = _tmpl(name);
        return {
            force: false,
            mode: '644',
            path: `${stringcase.spinalcase(name)}.json`,
            tmpl: tmpl,
            data: {
                name: name,
                pkg: pkg,
                params: params,
                domain: params.domain || pkg.name,
                get user() {
                    // Mysql username must shorter than 16, and 4 letters should be reserved for suffix like '_dev'.
                    let USERNAME_MAX_LENGTH = 12;
                    let user = stringcase.spinalcase(pkg.name).replace(/\-/g, '');
                    return user.slice(0, USERNAME_MAX_LENGTH);
                },
                get password() {
                    return uuid.v4().slice(0, 8);
                }
            }
        }
    });
}

module.exports = setup;
